@@ -1,9 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
-//
+
 //  RQuantLib function BermudanSwaption
 //
 //  Copyright (C) 2005 - 2007  Dominick Samperi
-//  Copyright (C) 2007 - 2018  Dirk Eddelbuettel
+//  Copyright (C) 2007 - 2019  Dirk Eddelbuettel
 //  Copyright (C) 2016         Terry Leitch
 //
 //  This file is part of RQuantLib.
@@ -24,17 +23,17 @@
 #include <rquantlib_internal.h>
 
 // Calibrates underlying swaptions to the input volatility matrix.
-void calibrateModel(const boost::shared_ptr<QuantLib::ShortRateModel>& model,
-                    const std::vector<boost::shared_ptr<QuantLib::CalibrationHelper> > &helpers,
+void calibrateModel(const QuantLib::ext::shared_ptr<QuantLib::ShortRateModel>& model,
+                    const std::vector<QuantLib::ext::shared_ptr<QuantLib::BlackCalibrationHelper> > &helpers,
                     QuantLib::Real lambda,
-                    Rcpp::NumericVector &swaptionMat, 
-                    Rcpp::NumericVector &swapLengths, 
+                    Rcpp::NumericVector &swaptionMat,
+                    Rcpp::NumericVector &swapLengths,
                     Rcpp::NumericMatrix &swaptionVols) {
 
     QuantLib::Size numRows = swaptionVols.nrow();
     QuantLib::Size numCols = swaptionVols.ncol();
     QuantLib::LevenbergMarquardt om;
-    
+
     model->calibrate(helpers, om,QuantLib:: EndCriteria(400,100,1.0e-8, 1.0e-8, 1.0e-8));
 
     // Output the implied Black volatilities
@@ -45,10 +44,10 @@ void calibrateModel(const boost::shared_ptr<QuantLib::ShortRateModel>& model,
 	QuantLib::Volatility diff = implied - swaptionVols(i, numCols-i-1);
 
 	Rprintf((char*) "%dx%d: model %lf, market %lf, diff %lf\n",
-            swaptionMat[i], swapLengths[numCols-i-1], implied, 
+            swaptionMat[i], swapLengths[numCols-i-1], implied,
             swaptionVols(i, numCols-i-1), diff);
-    }	
-}	
+    }
+}
 
 // [[Rcpp::export]]
 Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
@@ -63,11 +62,11 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
 
     double notional = 10000; // prices in basis points
 
-    QuantLib::Date todaysDate(Rcpp::as<QuantLib::Date>(rparam["tradeDate"])); 
-    QuantLib::Date settlementDate(Rcpp::as<QuantLib::Date>(rparam["settleDate"])); 
-    QuantLib::Date startDate(Rcpp::as<QuantLib::Date>(rparam["startDate"])); 
-    QuantLib::Date maturity(Rcpp::as<QuantLib::Date>(rparam["maturity"])); 
-    
+    QuantLib::Date todaysDate(Rcpp::as<QuantLib::Date>(rparam["tradeDate"]));
+    QuantLib::Date settlementDate(Rcpp::as<QuantLib::Date>(rparam["settleDate"]));
+    QuantLib::Date startDate(Rcpp::as<QuantLib::Date>(rparam["startDate"]));
+    QuantLib::Date maturity(Rcpp::as<QuantLib::Date>(rparam["maturity"]));
+
     //cout << "TradeDate: " << todaysDate << endl << "Settle: " << settlementDate << endl;
 
     RQLContext::instance().settleDate = settlementDate;
@@ -75,34 +74,34 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
 
     double strike = Rcpp::as<double>(rparam["strike"]);
     std::string method = Rcpp::as<std::string>(rparam["method"]);
-    
+
     // initialise from the singleton instance
     QuantLib::Calendar calendar = RQLContext::instance().calendar;
     //Integer fixingDays = RQLContext::instance().fixingDays;
 
     // Any DayCounter would be fine.
     // ActualActual::ISDA ensures that 30 years is 30.0
-    QuantLib::DayCounter termStructureDayCounter = 
+    QuantLib::DayCounter termStructureDayCounter =
         QuantLib::ActualActual(QuantLib::ActualActual::ISDA);
 
-    boost::shared_ptr<QuantLib::Quote> flatRate(new QuantLib::SimpleQuote(yield[0]));  // FIXME: hardcoded?
-    QuantLib::Handle<QuantLib::YieldTermStructure> 
-        rhTermStructure(boost::shared_ptr<QuantLib::FlatForward>(new QuantLib::FlatForward(settlementDate, 
+    QuantLib::ext::shared_ptr<QuantLib::Quote> flatRate(new QuantLib::SimpleQuote(yield[0]));  // FIXME: hardcoded?
+    QuantLib::Handle<QuantLib::YieldTermStructure>
+        rhTermStructure(QuantLib::ext::shared_ptr<QuantLib::FlatForward>(new QuantLib::FlatForward(settlementDate,
                                                                                            QuantLib::Handle<QuantLib::Quote>(flatRate),
                                                                                            QuantLib::Actual365Fixed())));
 
     // Get swaption vol matrix.
     //Rcpp::NumericMatrix swaptionVols(vols);
-    int dim1 = swaptionVols.nrow(); 
-    int dim2 = swaptionVols.ncol(); 
-	
+    int dim1 = swaptionVols.nrow();
+    int dim2 = swaptionVols.ncol();
+
     // Get swaption maturities
     //Rcpp::NumericVector swaptionMat(maturities);
-    int numRows = swaptionMat.size(); 
+    int numRows = swaptionMat.size();
 
     // Get swap tenors
     //Rcpp::NumericVector swapLengths(tenors);
-    int numCols = swapLengths.size(); 
+    int numCols = swapLengths.size();
 
     if (numRows*numCols != dim1*dim2) {
         std::ostringstream oss;
@@ -120,9 +119,9 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
     QuantLib::DayCounter fixedLegDayCounter = QuantLib::Thirty360(QuantLib::Thirty360::European);
     QuantLib::Frequency floatingLegFrequency = QuantLib::Semiannual;
     QuantLib::Rate dummyFixedRate = 0.03;
-    boost::shared_ptr<QuantLib::IborIndex> indexSixMonths(new QuantLib::Euribor6M(rhTermStructure));
-        
-    //QuantLib::Date startDate = calendar.advance(settlementDate, 1, QuantLib::Years, floatingLegConvention);  //took out hard coded 
+    QuantLib::ext::shared_ptr<QuantLib::IborIndex> indexSixMonths(new QuantLib::Euribor6M(rhTermStructure));
+
+    //QuantLib::Date startDate = calendar.advance(settlementDate, 1, QuantLib::Years, floatingLegConvention);  //took out hard coded
     //QuantLib::Date maturity = calendar.advance(startDate, 5, QuantLib::Years, floatingLegConvention);         //dates
     QuantLib::Schedule fixedSchedule(startDate,maturity,
                                      QuantLib::Period(fixedLegFrequency),calendar,
@@ -133,13 +132,13 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
                                      floatingLegConvention,floatingLegConvention,
                                      QuantLib::DateGeneration::Forward,false);
     QuantLib::VanillaSwap::Type type = QuantLib::VanillaSwap::Payer;
-    boost::shared_ptr<QuantLib::VanillaSwap> 
+    QuantLib::ext::shared_ptr<QuantLib::VanillaSwap>
         swap(new QuantLib::VanillaSwap(type, notional,
                                        fixedSchedule, dummyFixedRate, fixedLegDayCounter,
                                        floatSchedule, indexSixMonths, 0.0,
                                        indexSixMonths->dayCounter()));
-    swap->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
-        
+    swap->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
+
     // Find the ATM or break-even rate
     QuantLib::Rate fixedATMRate = swap->fairRate();
 
@@ -148,14 +147,14 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         fixedRate = fixedATMRate * (-strike);
     else
         fixedRate = strike;
-        
+
     // The swap underlying the Bermudan swaption.
-    boost::shared_ptr<QuantLib::VanillaSwap> 
+    QuantLib::ext::shared_ptr<QuantLib::VanillaSwap>
         mySwap(new QuantLib::VanillaSwap(type, notional,
                                          fixedSchedule, fixedRate, fixedLegDayCounter,
                                          floatSchedule, indexSixMonths, 0.0,
                                          indexSixMonths->dayCounter()));
-    swap->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
+    swap->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
 
     // Build swaptions that will be used to calibrate model to
     // the volatility matrix.
@@ -164,21 +163,21 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         swaptionMaturities.push_back(QuantLib::Period(swaptionMat[i], QuantLib::Years));
 
     // Swaptions used for calibration
-    std::vector<boost::shared_ptr<QuantLib::CalibrationHelper> > swaptions;
+    std::vector<QuantLib::ext::shared_ptr<QuantLib::BlackCalibrationHelper> > swaptions;
 
     // List of times that have to be included in the timegrid
     std::list<QuantLib::Time> times;
     for (i=0; i<(QuantLib::Size)numRows; i++) {
-        //boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
-        boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
-        swaptions.push_back(boost::shared_ptr<QuantLib::CalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
-                                                                                                        QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
-                                                                                                        QuantLib::Handle<QuantLib::Quote>(vol),
-                                                                                                        indexSixMonths,
-                                                                                                        indexSixMonths->tenor(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        rhTermStructure)));
+        //QuantLib::ext::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
+        QuantLib::ext::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
+        swaptions.push_back(QuantLib::ext::shared_ptr<QuantLib::BlackCalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
+                                                                                                             QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
+                                                                                                             QuantLib::Handle<QuantLib::Quote>(vol),
+                                                                                                             indexSixMonths,
+                                                                                                             indexSixMonths->tenor(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             rhTermStructure)));
         swaptions.back()->addTimesTo(times);
 
     }
@@ -188,23 +187,23 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
 
     // Get Bermudan swaption exercise dates.
     std::vector<QuantLib::Date> bermudanDates;
-    const std::vector<boost::shared_ptr<QuantLib::CashFlow> >& leg = swap->fixedLeg();
+    const std::vector<QuantLib::ext::shared_ptr<QuantLib::CashFlow> >& leg = swap->fixedLeg();
     for (i=0; i<leg.size(); i++) {
-        boost::shared_ptr<QuantLib::Coupon> coupon = boost::dynamic_pointer_cast<QuantLib::Coupon>(leg[i]);
+        QuantLib::ext::shared_ptr<QuantLib::Coupon> coupon = QuantLib::ext::dynamic_pointer_cast<QuantLib::Coupon>(leg[i]);
         bermudanDates.push_back(coupon->accrualStartDate());
     }
-    boost::shared_ptr<QuantLib::Exercise> bermudaExercise(new QuantLib::BermudanExercise(bermudanDates));
+    QuantLib::ext::shared_ptr<QuantLib::Exercise> bermudaExercise(new QuantLib::BermudanExercise(bermudanDates));
 
     // Price based on method selected.
     if (method.compare("G2Analytic") == 0) {
 
-        boost::shared_ptr<QuantLib::G2> modelG2(new QuantLib::G2(rhTermStructure));
+        QuantLib::ext::shared_ptr<QuantLib::G2> modelG2(new QuantLib::G2(rhTermStructure));
         Rprintf((char*)"G2/Jamshidian (analytic) calibration\n");
         for(i = 0; i < swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::G2SwaptionEngine(modelG2, 6.0, 16)));
-        calibrateModel(modelG2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols); 
-        boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelG2, 50));
-        QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise); 
+            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::G2SwaptionEngine(modelG2, 6.0, 16)));
+        calibrateModel(modelG2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
+        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelG2, 50));
+        QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a")         = modelG2->params()[0],
                                   Rcpp::Named("sigma")     = modelG2->params()[1],
@@ -217,12 +216,12 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
 
     } else if (method.compare("HWAnalytic") == 0) {
 
-        boost::shared_ptr<QuantLib::HullWhite> modelHW(new QuantLib::HullWhite(rhTermStructure));
+        QuantLib::ext::shared_ptr<QuantLib::HullWhite> modelHW(new QuantLib::HullWhite(rhTermStructure));
         Rprintf((char*)"Hull-White (analytic) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::JamshidianSwaptionEngine(modelHW)));
+            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::JamshidianSwaptionEngine(modelHW)));
         calibrateModel(modelHW, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW, 50));
+        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW, 50));
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelHW->params()[0],
@@ -232,13 +231,13 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         //Rcpp::Named("params") = params);
 
     } else if (method.compare("HWTree") == 0) {
-        boost::shared_ptr<QuantLib::HullWhite> modelHW2(new QuantLib::HullWhite(rhTermStructure));
+        QuantLib::ext::shared_ptr<QuantLib::HullWhite> modelHW2(new QuantLib::HullWhite(rhTermStructure));
         Rprintf((char*)"Hull-White (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelHW2,grid)));
+            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelHW2,grid)));
 
         calibrateModel(modelHW2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW2, 50));
+        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW2, 50));
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelHW2->params()[0],
@@ -248,13 +247,13 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         //Rcpp::Named("params") = params);
 
     } else if (method.compare("BKTree") == 0) {
-        boost::shared_ptr<QuantLib::BlackKarasinski> modelBK(new QuantLib::BlackKarasinski(rhTermStructure));
+        QuantLib::ext::shared_ptr<QuantLib::BlackKarasinski> modelBK(new QuantLib::BlackKarasinski(rhTermStructure));
         Rprintf((char*)"Black-Karasinski (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
-            swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelBK,grid)));
+            swaptions[i]->setPricingEngine(QuantLib::ext::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelBK,grid)));
         calibrateModel(modelBK, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
 
-        boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelBK, 50));
+        QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelBK, 50));
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a") = modelBK->params()[0],
@@ -262,7 +261,7 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
                                   Rcpp::Named("price") = bermudanSwaption.NPV(),
                                   Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params") = params);
- 
+
     } else {
         throw std::range_error("Unknown method in BermudanSwaption\n");
     }
@@ -271,57 +270,57 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
 
 // [[Rcpp::export]]
 Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
-                                  std::vector<QuantLib::Date> dateVec, 
+                                  std::vector<QuantLib::Date> dateVec,
                                   std::vector<double> zeroVec,
                                   Rcpp::NumericVector swaptionMat,
                                   Rcpp::NumericVector swapLengths,
                                   Rcpp::NumericMatrix swaptionVols) {
-    
+
    // std::vector<std::string> tsnames = tslist.names();
 
-    
+
     QuantLib::Size i;
     //int *swaptionMat=0, *swapLengths=0;
     //double **swaptionVols=0;
 
     double notional = 10000; // prices in basis points
 
-    QuantLib::Date todaysDate(Rcpp::as<QuantLib::Date>(rparam["tradeDate"])); 
-    QuantLib::Date settlementDate(Rcpp::as<QuantLib::Date>(rparam["settleDate"])); 
-    QuantLib::Date startDate(Rcpp::as<QuantLib::Date>(rparam["startDate"])); 
-    QuantLib::Date maturity(Rcpp::as<QuantLib::Date>(rparam["maturity"])); 
+    QuantLib::Date todaysDate(Rcpp::as<QuantLib::Date>(rparam["tradeDate"]));
+    QuantLib::Date settlementDate(Rcpp::as<QuantLib::Date>(rparam["settleDate"]));
+    QuantLib::Date startDate(Rcpp::as<QuantLib::Date>(rparam["startDate"]));
+    QuantLib::Date maturity(Rcpp::as<QuantLib::Date>(rparam["maturity"]));
     bool payfix = Rcpp::as<bool>(rparam["payFixed"]);
 
-    
+
     //cout << "TradeDate: " << todaysDate << endl << "Settle: " << settlementDate << endl;
-    
+
     RQLContext::instance().settleDate = settlementDate;
     QuantLib::Settings::instance().evaluationDate() = todaysDate;
 
     // initialise from the singleton instance
     QuantLib::Calendar calendar = RQLContext::instance().calendar;
     //Integer fixingDays = RQLContext::instance().fixingDays;
-    
+
     double strike = Rcpp::as<double>(rparam["strike"]);
     std::string method = Rcpp::as<std::string>(rparam["method"]);
-    
-    QuantLib::Handle<QuantLib::YieldTermStructure> 
+
+    QuantLib::Handle<QuantLib::YieldTermStructure>
         rhTermStructure(rebuildCurveFromZeroRates(dateVec, zeroVec));
 
     // Get swaption maturities
     //Rcpp::NumericVector swaptionMat(maturities);
-    int numRows = swaptionMat.size(); 
-    
+    int numRows = swaptionMat.size();
+
     // Get swaption vol matrix.
     //Rcpp::NumericMatrix swaptionVols(vols);
-    int dim1 = swaptionVols.nrow(); 
-    int dim2 = swaptionVols.ncol(); 
-    
-    
+    int dim1 = swaptionVols.nrow();
+    int dim2 = swaptionVols.ncol();
+
+
     // Get swap tenors
     //Rcpp::NumericVector swapLengths(tenors);
-    int numCols = swapLengths.size(); 
-    
+    int numCols = swapLengths.size();
+
     if (numRows*numCols != dim1*dim2) {
         std::ostringstream oss;
         oss << "Swaption vol matrix size (" << dim1 << " x " << dim2 << ") "
@@ -330,7 +329,7 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
             << numCols << ")";
         throw std::range_error(oss.str());
     }
-    
+
     // Create dummy swap to get schedules.
     QuantLib::Frequency fixedLegFrequency = QuantLib::Annual;
     QuantLib::BusinessDayConvention fixedLegConvention = QuantLib::Unadjusted;
@@ -338,9 +337,9 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
     QuantLib::DayCounter fixedLegDayCounter = QuantLib::Thirty360(QuantLib::Thirty360::European);
     QuantLib::Frequency floatingLegFrequency = QuantLib::Semiannual;
     QuantLib::Rate dummyFixedRate = 0.03;
-    boost::shared_ptr<QuantLib::IborIndex> indexSixMonths(new QuantLib::Euribor6M(rhTermStructure));
+    QuantLib::ext::shared_ptr<QuantLib::IborIndex> indexSixMonths(new QuantLib::Euribor6M(rhTermStructure));
 
-    //QuantLib::Date startDate = calendar.advance(settlementDate, 1, QuantLib::Years, floatingLegConvention);  //took out hard coded 
+    //QuantLib::Date startDate = calendar.advance(settlementDate, 1, QuantLib::Years, floatingLegConvention);  //took out hard coded
     //QuantLib::Date maturity = calendar.advance(startDate, 5, QuantLib::Years, floatingLegConvention);         //dates
     QuantLib::Schedule fixedSchedule(startDate,maturity,
                                      QuantLib::Period(fixedLegFrequency),calendar,
@@ -356,19 +355,19 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
         type = QuantLib::VanillaSwap::Payer;
     } else{
         type = QuantLib::VanillaSwap::Receiver;
-    }   
+    }
 
 
-    boost::shared_ptr<QuantLib::VanillaSwap> 
+    boost::shared_ptr<QuantLib::VanillaSwap>
         swap(new QuantLib::VanillaSwap(type, notional,
                                        fixedSchedule, dummyFixedRate, fixedLegDayCounter,
                                        floatSchedule, indexSixMonths, 0.0,
                                        indexSixMonths->dayCounter()));
     swap->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::DiscountingSwapEngine(rhTermStructure)));
-    
+
     // Find the ATM or break-even rate
     QuantLib::Rate fixedATMRate = swap->fairRate();
-    
+
     QuantLib::Rate fixedRate;
     if(strike < 0) // factor instead of real strike
         fixedRate = fixedATMRate * (-strike);
@@ -376,7 +375,7 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
         fixedRate = strike;
 
     // The swap underlying the Bermudan swaption.
-    boost::shared_ptr<QuantLib::VanillaSwap> 
+    boost::shared_ptr<QuantLib::VanillaSwap>
         mySwap(new QuantLib::VanillaSwap(type, notional,
                                          fixedSchedule, fixedRate, fixedLegDayCounter,
                                          floatSchedule, indexSixMonths, 0.0,
@@ -388,9 +387,9 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
     std::vector<QuantLib::Period> swaptionMaturities;
     for(i = 0; i < (QuantLib::Size)numRows; i++)
         swaptionMaturities.push_back(QuantLib::Period(swaptionMat[i], QuantLib::Years));
-    
+
     // Swaptions used for calibration
-    std::vector<boost::shared_ptr<QuantLib::CalibrationHelper> > swaptions;
+    std::vector<boost::shared_ptr<QuantLib::BlackCalibrationHelper> > swaptions;
 
     // List of times that have to be included in the timegrid
     std::list<QuantLib::Time> times;
@@ -398,21 +397,21 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
 
         //boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
         boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
-        swaptions.push_back(boost::shared_ptr<QuantLib::CalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
-                                                                                                        QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
-                                                                                                        QuantLib::Handle<QuantLib::Quote>(vol),
-                                                                                                        indexSixMonths,
-                                                                                                        indexSixMonths->tenor(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        rhTermStructure)));
+        swaptions.push_back(boost::shared_ptr<QuantLib::BlackCalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
+                                                                                                             QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
+                                                                                                             QuantLib::Handle<QuantLib::Quote>(vol),
+                                                                                                             indexSixMonths,
+                                                                                                             indexSixMonths->tenor(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             rhTermStructure)));
         swaptions.back()->addTimesTo(times);
     }
 
     // Building time-grid
     QuantLib::TimeGrid grid(times.begin(), times.end(), 30);
 
-    
+
     // Get Bermudan swaption exercise dates.
     std::vector<QuantLib::Date> bermudanDates;
     const std::vector<boost::shared_ptr<QuantLib::CashFlow> >& leg = swap->fixedLeg();
@@ -425,14 +424,14 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
 
     // Price based on method selected.
     if (method.compare("G2Analytic") == 0) {
-        
+
         boost::shared_ptr<QuantLib::G2> modelG2(new QuantLib::G2(rhTermStructure));
         Rprintf((char*)"G2/Jamshidian (analytic) calibration\n");
         for(i = 0; i < swaptions.size(); i++)
             swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::G2SwaptionEngine(modelG2, 6.0, 16)));
-        calibrateModel(modelG2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols); 
+        calibrateModel(modelG2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
         boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelG2, 50));
-        QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise); 
+        QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
         return Rcpp::List::create(Rcpp::Named("a")         = modelG2->params()[0],
                                   Rcpp::Named("sigma")     = modelG2->params()[1],
@@ -442,9 +441,9 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
                                                                                                                                                                                                                   Rcpp::Named("price")     = bermudanSwaption.NPV(),
                                                                                                                                                                                                                   Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params")    = params);
-        
+
     } else if (method.compare("HWAnalytic") == 0) {
-        
+
         boost::shared_ptr<QuantLib::HullWhite> modelHW(new QuantLib::HullWhite(rhTermStructure));
         Rprintf((char*)"Hull-White (analytic) calibration\n");
         for (i=0; i<swaptions.size(); i++)
@@ -458,13 +457,13 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
                                                                           Rcpp::Named("price") = bermudanSwaption.NPV(),
                                                                           Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params") = params);
-        
+
     } else if (method.compare("HWTree") == 0) {
         boost::shared_ptr<QuantLib::HullWhite> modelHW2(new QuantLib::HullWhite(rhTermStructure));
         Rprintf((char*)"Hull-White (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
             swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelHW2,grid)));
-        
+
         calibrateModel(modelHW2, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
         boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelHW2, 50));
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
@@ -474,14 +473,14 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
                                                                            Rcpp::Named("price") = bermudanSwaption.NPV(),
                                                                            Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params") = params);
-        
+
     } else if (method.compare("BKTree") == 0) {
         boost::shared_ptr<QuantLib::BlackKarasinski> modelBK(new QuantLib::BlackKarasinski(rhTermStructure));
         Rprintf((char*)"Black-Karasinski (tree) calibration\n");
         for (i=0; i<swaptions.size(); i++)
             swaptions[i]->setPricingEngine(boost::shared_ptr<QuantLib::PricingEngine>(new QuantLib::TreeSwaptionEngine(modelBK,grid)));
         calibrateModel(modelBK, swaptions, 0.05, swaptionMat, swapLengths, swaptionVols);
-        
+
         boost::shared_ptr<QuantLib::PricingEngine> engine(new QuantLib::TreeSwaptionEngine(modelBK, 50));
         QuantLib::Swaption bermudanSwaption(mySwap, bermudaExercise);
         bermudanSwaption.setPricingEngine(engine);
@@ -490,9 +489,9 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
                                                                           Rcpp::Named("price") = bermudanSwaption.NPV(),
                                                                           Rcpp::Named("ATMStrike") = fixedATMRate);
         //Rcpp::Named("params") = params);
-        
+
     } else {
         throw std::range_error("Unknown method in BermudanSwaption\n");
     }
-    
+
 }
